
#ifndef __SENSE_UK_H__
#define __SENSE_UK_H__

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000


#ifdef __cplusplus
extern "C" {
#endif


#if defined WIN32 || defined _WIN32 || defined _WIN64
#include <windows.h>
#endif


  

/**********  control type(The value of dwCtrCode parameter of UKControl function ) ***********/
#define UK_GET_SERIAL_NUMBER    0x00000001    //Get serial number





/************************************************************************\
Function
    Get flash disk drive letter
Parameters
    CHAR *pcLetter                  Flash disk drive letter
Return value
    TRUE                            Operation succeed
    FALSE                           Operation failed
\************************************************************************/
BOOL WINAPI UKGetRemovalLetter(OUT CHAR *pcLetter);


/************************************************************************\
Function
    Get CDROM drive letter
Parameters
    CHAR *pcLetter                  CDROM drive letter
Return value
    TRUE                            Operation succeed
    FALSE                           Operation failed
\************************************************************************/
BOOL WINAPI UKGetCdromLetter(OUT CHAR *pcLetter);


/************************************************************************\
Function
    operate corresponding function according to the control code
Parameters
    CHAR  cLetter                   Flash disk driveletter
    DWORD dwCtrCode                 control word
    VOID *pInBuffer                 Input buffer point, storage control commanded requires additional data
    DWORD dwInBufferLen             Input buffer pInBuffer data length
    VOID *pOutBuffer                Output buffer point store data that device returns after sending control word
    DWORD dwOutBufferLen            The size of the output buffer
    DWORD *pdwBytesReturned         The variable address, to store the actual return to pOutBuffer buffer data lengthThe parameter can not be NULL
Return value
    TRUE                            Operation succeed
    FALSE                           Operation failed
\************************************************************************/    
BOOL WINAPI UKControl(IN  CHAR  cLetter, 
                      IN  DWORD dwCtrCode,
                      IN  VOID  *pInBuffer,
                      IN  DWORD dwInBufferLen,
                      OUT VOID  *pOutBuffer,
                      IN  DWORD dwOutBufferLen,
                      OUT DWORD *pdwBytesReturned);


/************************************************************************\
Function
    Write data in the hidden area
Parameters
    CHAR  cLetter                   Flash disk drive letter
    DWORD WritePos                  Write the initial offset,base zero.
    UCHAR *pWriteBuff               Write data content
    DWORD WriteLength               Write data length
Return
    TRUE                            Operation succeed
    FALSE                           Operation failed
\************************************************************************/
BOOL WINAPI UKHiddenAreaWrite(IN CHAR  cLetter, 
                              IN DWORD WritePos, 
                              IN UCHAR *pWriteBuff, 
                              IN DWORD WriteLength);


/************************************************************************\
Function
    Read out the hidden area data 
Parameters
    CHAR  cLetter                   Flash disk drive letter
    DWORD ReadPos                   Read the initial offset,base zero.
    UCHAR *pReadBuff                Read data content
    DWORD ReadLength                Read data lenth
Return value
    TRUE                            Operation succeed
    FALSE                           Operation failed
\************************************************************************/
BOOL WINAPI UKHiddenAreaRead(IN  CHAR  cLetter, 
                             IN  DWORD ReadPos, 
                             OUT UCHAR *pReadBuff, 
                             IN  DWORD ReadLength);


/************************************************************************\
Function
    Set the TDES key (all hidden area data use the same key)
    Please encrypt data when reading it, while decrypt data when writing it.
    Otherwise, the data would be saved as plaintext.
Parameters
    UCHAR *pTdesKey                 TDES key length must be equal to 16 bytes. (Can not be all 0x00)
Return value
    TRUE                            Operation succeed
    FALSE                           Operation failed
\************************************************************************/
BOOL WINAPI UKSetTdesKey(IN UCHAR *pTdesKey);


/************************************************************************\
Function
    Security area, Login authentication
Parameters
    CHAR cLetter                    Flash disk drive letter
    CHAR* pLoginPass                Login password, no longer than 32 bytes. (Can be NULL)
Return value
    TRUE                            Operation succeed
    FALSE                           Operation failed
\************************************************************************/
BOOL WINAPI UKPassAreaLogin(IN CHAR cLetter, 
                            IN CHAR *pLoginPass);


/************************************************************************\
Function
    Security area ,Logout 
Parameters
    CHAR cLetter                    Flash disk drive letter
Return value
    TRUE                            Operation succeed
    FALSE                           Operation failed
\************************************************************************/
BOOL WINAPI UKPassAreaLogout(IN CHAR cLetter);


/************************************************************************\
Function
    Security area, Change password
Parameters
    CHAR  cLetter                   Flash disk drive letter
    CHAR* pOldPass                  Old password, the length does not exceed 32 bytes. (Can be NULL)
    CHAR* pNewPass                  New password, the length does not exceed 32 bytes. (Can be NULL)
Return value
    TRUE                            Operation succeed
    FALSE                           Operation failed
\************************************************************************/
BOOL WINAPI UKPassAreaChangePwd(IN CHAR cLetter, 
                                IN CHAR *pOldPass,
                                IN CHAR *pNewPass);


/************************************************************************\
Function
    Hide or displaythe drive letter
Parameters
    cLetter                         The drive letter need to operate
    bHide                           True -- hide, FALSE -- display
Return value
    TRUE                            Operation succeed
    FALSE                           Operation failed
\************************************************************************/
BOOL WINAPI UKPassAreaHideDrive(IN CHAR cLetter, 
                                IN BOOL bHide = TRUE);


/************************************************************************\
Function
    Write ISO file in CDROM
Parameters
    CHAR  cLetter                   CDROM drive letter
    CHAR  *pFilePathName            The pointer to ISO file path name
Return value
    TRUE                            Operation succeed
    FALSE                           Operation failed
\************************************************************************/
BOOL WINAPI UKWriteCdrom(IN CHAR cLetter, 
                         IN CHAR *pFilePathName);


/************************************************************************\
Function
    Flash disk re-partition 
Parameters
    DWORD dwPublicSize              Public area size(mb)
    DWORD dwSecuritySize            Security area size(mb)
    DWORD dwIndLunSize              When the partition mode is 2/3/4/5, it means the cdrom or pure public area size(mb)
    DWORD dwResvAreaSize            Hidden area size(mb)
    INT   nCurrentMode              Partition mode(0-Public only 1-Public/Security(1-Lun) 2-CDROM + Public (2-Luns)
                                                   3-Public + Public/Security (2-Luns) 4-CDROM + Public/Security(2-Luns)
                                                   5-CDROM only)
    CHAR  cLetter                   Flash disk drive letter
Return value
    TRUE                            Operation succeed
    FALSE                           Operation failed
\************************************************************************/
BOOL WINAPI UKSetDiskCurrentMode( IN DWORD dwPublicSize, 
                                  IN DWORD dwSecuritySize, 
                                  IN DWORD dwIndLunSize, 
                                  IN DWORD dwResvAreaSize, 
                                  IN INT   nCurrentMode,
                                  IN CHAR  cLetter);

/************************************************************************\
Function
    Get flash disk partition size
Parameters
    DWORD *pdwTotalSize             Pointer to total capacity(mb) 
    DWORD *pdwPublicSize            Pointer to public area size(mb)
    DWORD *pdwSecuritySize          Pointer to security area size(mb)  
    DWORD *pdwIndLunSize            When the partition mode is 2/3/4/5, it means the cdrom or pure public area size(mb)
    DWORD *pdwResvAreaSize          Pointer to hidden area size(mb)
    INT   *pnCurrentMode            Current pointer to partition mode
    CHAR  cLetter                   Flash disk drive letter
Return value
    TRUE                            Operation succeed
    FALSE                           Operation failed
\************************************************************************/                  
BOOL WINAPI UKGetDiskCurrentMode( OUT DWORD *pdwTotalSize, 
                                  OUT DWORD *pdwPublicSize, 
                                  OUT DWORD *pdwSecuritySize, 
                                  OUT DWORD *pdwIndLunSize, 
                                  OUT DWORD *pdwResvAreaSize, 
                                  OUT INT   *pnCurrentMode,
                                  IN  CHAR  cLetter);


/************************************************************************\
Function
    Get the API version
Parameters
    
Return value
    DWORD  API version  
\************************************************************************/                  
DWORD WINAPI UKGetApiVersion();



#ifdef __cplusplus
}
#endif


#endif //__SENSE_UK_H__